Installazione di ONLYOFFICE Workspace Community utilizzando parametri aggiuntivi dello script
Introduzione
ONLYOFFICE Workspace Community è una versione gratuita del sistema collaborativo sviluppato per gestire documenti, progetti, relazioni con i clienti e corrispondenza e-mail, tutto in un unico posto.
ONLYOFFICE Workspace Community viene distribuito come script di installazione automatica per i sistemi operativi Linux con Docker installato. Lo script configura i container Docker con tutti i componenti necessari per il corretto funzionamento di ONLYOFFICE Workspace Community ed è facile da eseguire, gestire e aggiornare.
Dopo aver scaricato lo script di installazione di ONLYOFFICE Workspace Community, potrebbe essere necessario eseguirlo con parametri aggiuntivi, ad esempio per installare ogni componente su un server separato. Usa il seguente comando per visualizzare l'elenco di tutti i parametri disponibili dello script:
bash workspace-install.sh -h
Di seguito troverai una breve descrizione e alcuni esempi di utilizzo di questi parametri.
Nome dell'immagine
| Parametro | Descrizione |
|---|---|
-ci, --communityimage | Nome dell'immagine di ONLYOFFICE Community Server |
-di, --documentimage | Nome dell'immagine di ONLYOFFICE Docs |
-mi, --mailimage | Nome dell'immagine di ONLYOFFICE Mail |
-cpi, --controlpanelimage | Nome dell'immagine di ONLYOFFICE Control Panel |
Questi parametri specificano il nome dell'immagine da cui deve essere avviato un container. L'immagine specificata deve essere disponibile nel repository pubblico ufficiale su Docker Hub.
Esempio
bash workspace-install.sh -ims false -di onlyoffice/documentserver -ics true -icp true
Verrà eseguito un container dall'immagine specificata di ONLYOFFICE Docs archiviata nel repository, oltre ai container di ONLYOFFICE Community Server e ONLYOFFICE Control Panel.
Versione del componente
| Parametro | Descrizione |
|---|---|
-cv, --communityversion | Versione di ONLYOFFICE Community Server |
-dv, --documentversion | Versione di ONLYOFFICE Docs |
-mv, --mailversion | Versione di ONLYOFFICE Mail |
-cpv, --controlpanelversion | Versione di ONLYOFFICE Control Panel |
Questi parametri consentono di installare una versione specifica di un componente se non desideri usare l'ultima versione disponibile nel repository. Per impostazione predefinita, per eseguire il container di ogni componente viene usata un'immagine con il tag latest.
Esempio
Apri il repository Docker Hub nel browser, seleziona il componente e vai alla scheda Tags per visualizzare tutti i tag disponibili. Specifica la versione che desideri installare per i componenti necessari:
bash workspace-install.sh -ics true -cv 8.9.0.150 -ids false -icp true -cpv 1.6.0.52 -ims true -md "yourdomain.com"
Verranno installate la versione 8.9.0.150 di ONLYOFFICE Community Server, la versione 1.6.0.52 di ONLYOFFICE Control Panel e l'ultima versione di ONLYOFFICE Mail, poiché la sua versione non è stata specificata esplicitamente.
IP del server
| Parametro | Descrizione |
|---|---|
-dip, --documentserverip | Indirizzo IP di ONLYOFFICE Docs |
-mip, --mailserverip | Indirizzo IP di ONLYOFFICE Mail |
-mdbip, --mailserverdbip | Indirizzo IP del database di ONLYOFFICE Mail |
Questi parametri possono essere usati per collegare i componenti se li installi su macchine separate.
Esempio
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Verrà installato ONLYOFFICE Community Server con ONLYOFFICE Control Panel e verrà collegato a ONLYOFFICE Docs installato su un'altra macchina con indirizzo IP 192.168.3.202.
Nome di dominio di ONLYOFFICE Mail
| Parametro | Descrizione |
|---|---|
-md, --maildomain | Nome di dominio di ONLYOFFICE Mail |
Questo parametro consente di specificare un nome di dominio personalizzato che verrà usato per ONLYOFFICE Mail.
Esempio
bash workspace-install.sh -md "yourdomain.com"
Verranno installati tutti i componenti di ONLYOFFICE Workspace Community, incluso ONLYOFFICE Mail, con il nome di dominio yourdomain.com specificato.
Il tuo dominio che verrà utilizzato per mantenere la corrispondenza deve essere valido e configurato per questa macchina (ovvero deve avere il record A appropriato nelle impostazioni DNS che punti il nome del dominio all'indirizzo IP della macchina su cui è installato ONLYOFFICE Mail).
Nel comando precedente, il parametro "yourdomain.com" deve essere inteso come dominio di servizio per ONLYOFFICE Mail. Di solito è specificato nel record MX del dominio che verrà utilizzato per mantenere la corrispondenza. Di norma, "yourdomain.com" ha l'aspetto di mx1.onlyoffice.com
Aggiornamento dei componenti
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-u, --update | da usare per aggiornare i componenti esistenti | true|false | false |
Questo parametro installa le ultime versioni dei componenti obsoleti se i componenti corrispondenti installati sulla tua macchina sono obsoleti.
Esempio
bash workspace-install.sh -u true
Verranno arrestati i container che richiedono l'aggiornamento, rimossi e avviate le ultime versioni dei componenti ONLYOFFICE Workspace corrispondenti. I container la cui versione attuale corrisponde all'ultima disponibile non saranno interessati. Anche i componenti saltati durante l'installazione precedente verranno saltati. I dati del portale verranno conservati automaticamente.
Credenziali
| Parametro | Descrizione |
|---|---|
-un, --username | nome utente di dockerhub |
-p, --password | password di dockerhub |
Questi parametri vengono usati quando vengono fornite le credenziali per accedere a un repository di test, consentendoti di eseguire container dalle immagini archiviate al suo interno.
Esempio
bash workspace-install.sh -md "yourdomain.com" -un username -p password
Installazione dei componenti
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-ics, --installcommunityserver | installa ONLYOFFICE Community Server | true|false|pull | true |
-ids, --installdocumentserver | installa ONLYOFFICE Docs | true|false|pull | true |
-ims, --installmailserver | installa ONLYOFFICE Mail | true|false|pull | true |
-icp, --installcontrolpanel | installa ONLYOFFICE Control Panel | true|false|pull | true |
Questi parametri consentono di specificare se installare un determinato componente. Possono essere usati per installare ogni componente su un server separato.
- Usa il valore
trueper installare un componente. - Usa il valore
falseper saltare l'installazione di un componente. - Usa il valore
pullper scaricare un componente senza installarlo.
Esempio
bash workspace-install.sh -ims false
Verranno installati tutti i componenti di ONLYOFFICE Workspace senza ONLYOFFICE Mail.
bash workspace-install.sh -ics false -ids true -icp false -ims false -es true
Verrà saltata l'installazione di ONLYOFFICE Mail, ONLYOFFICE Community Server e ONLYOFFICE Control Panel e verrà installato solo ONLYOFFICE Docs.
Tipo di installazione
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-it, --installation_type | tipo di installazione | WORKSPACE|WORKSPACE_ENTERPRISE | WORKSPACE_ENTERPRISE |
Questo parametro installa la soluzione specificata: ONLYOFFICE Workspace oppure ONLYOFFICE Workspace Enterprise Edition.
Esempio
bash workspace-install.sh -it GROUPS
Verrà installata la soluzione ONLYOFFICE Workspace, che include i componenti ONLYOFFICE Community Server e ONLYOFFICE Control Panel.
Utilizzo di un componente come server esterno
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-es, --useasexternalserver | usa come server esterno | true|false | false |
Questo parametro viene usato quando si installano i componenti su server separati.
- Usa il valore
truequando installi ONLYOFFICE Docs e ONLYOFFICE Mail su macchine separate. - Usa il valore
falsequando installi ONLYOFFICE Community Server insieme a ONLYOFFICE Control Panel su una macchina separata.
Esempio
bash workspace-install.sh -ics false -ids false -icp false -ims true -md "yourdomain.com" -es true
Verrà saltata l'installazione di ONLYOFFICE Docs, ONLYOFFICE Community Server e ONLYOFFICE Control Panel e verrà installato solo ONLYOFFICE Mail.
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Verrà installato ONLYOFFICE Community Server con ONLYOFFICE Control Panel e verrà collegato a ONLYOFFICE Docs installato su un'altra macchina.
Creazione del file di swap
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-ms, --makeswap | crea il file di swap | true|false | false |
Questo parametro crea un file di swap da 6 GB. Per impostazione predefinita è specificato il valore true, quindi non è necessario indicare questo parametro quando si esegue lo script. Il file di swap verrà creato automaticamente.
Esempio
bash workspace-install.sh -ms false
Se esiste già un file di swap, usa questo comando per evitare che ne venga creato uno nuovo durante l'installazione.
Se esegui di nuovo lo script senza il parametro -ms, verifica se onlyoffice_swapfile è presente. Se il file di swap esiste già, lo script non lo creerà di nuovo.
Server MySQL
| Parametro | Descrizione | Predefinito |
|---|---|---|
-mysqlh, --mysqlhost | Host del server MySQL | localhost |
-mysqlprt, --mysqlport | Porta del server MySQL | 3306 |
-mysqlru, --mysqlrootuser | Utente root del server MySQL | root |
-mysqlrp, --mysqlrootpassword | Password root del server MySQL | my-secret-pw |
Se non specifichi esplicitamente questi parametri, vengono usati i valori predefiniti.
Esempio
bash workspace-install.sh -mysqlru root -mysqlrp new-secret-pw
Questo comando imposta una password personalizzata per l'account root di MySQL durante l'installazione di ONLYOFFICE Workspace.
Database di ONLYOFFICE Community Server
| Parametro | Descrizione | Predefinito |
|---|---|---|
-mysqld, --mysqldatabase | Nome del database di ONLYOFFICE Community Server | onlyoffice |
-mysqlu, --mysqluser | Utente del database di ONLYOFFICE Community Server | onlyoffice_user |
-mysqlp, --mysqlpassword | Password del database di ONLYOFFICE Community Server | onlyoffice_pass |
Questi parametri consentono di creare il database di ONLYOFFICE Community Server con un nome personalizzato, insieme a un nome utente e una password per un account con permessi di superutente. Se non specifichi esplicitamente questi parametri, vengono usati i valori predefiniti.
Esempio
bash workspace-install.sh -mysqld communitydatabase -mysqlu username -mysqlp password
Database di ONLYOFFICE Mail
| Parametro | Descrizione | Predefinito |
|---|---|---|
-mysqlmd, --mysqlmaildatabase | Nome del database di ONLYOFFICE Mail | onlyoffice_mailserver |
-mysqlmu, --mysqlmailuser | Utente del database di ONLYOFFICE Mail | mail_admin |
-mysqlmp, --mysqlmailpassword | Password del database di ONLYOFFICE Mail | Isadmin123 |
Questi parametri consentono di creare il database di ONLYOFFICE Mail specificando un nome di database personalizzato, nonché un nome utente e una password per l'account con permessi di superutente sul database creato. Se non specifichi esplicitamente questi parametri, vengono usati i valori predefiniti.
Esempio
bash workspace-install.sh -md "mx.yourdomain.com" -mysqlmd maildatabase -mysqlmu username -mysqlmp password
Porta di ONLYOFFICE Community Server
| Parametro | Descrizione | Predefinito |
|---|---|---|
-cp, --communityport | Porta di ONLYOFFICE Community Server | 80 |
Questo parametro modifica la porta su cui viene eseguito ONLYOFFICE Community Server. La porta predefinita è la 80.
Esempio
bash workspace-install.sh -cp 8080
Impostazione per core.machinekey
| Parametro | Descrizione |
|---|---|
-mk, --machinekey | Impostazione per la chiave core.machinekey |
Questo parametro consente di specificare una machinekey personalizzata durante l'installazione di ONLYOFFICE Workspace Community.
Questo parametro viene scritto nel file di configurazione /app/onlyoffice/CommunityServer/data/.private/machinekey.
Esempio
bash workspace-install.sh -mk yourmachinekey
Impostazione per il segreto JWT
| Parametro | Descrizione |
|---|---|
-jwt, --jwtsecret | Impostazione per la chiave segreta JWT |
Questo parametro consente di specificare una chiave segreta JWT personalizzata durante l'installazione di ONLYOFFICE Workspace Community. La chiave segreta viene usata per firmare il token web JSON e convalidare il token nella richiesta a ONLYOFFICE Docs.
Questo parametro viene scritto nei seguenti file di configurazione (i percorsi sono specificati all'interno dei container):
- Per Community Server -
/var/www/onlyoffice/WebStudio/web.appsettings.config - Per Document Server -
/etc/onlyoffice/documentserver/local.json
Esempio
bash workspace-install.sh -jwt yoursecret